==> open-xchange-documentconverter-client_7.10.0.orig.tar.bz2: open-xchange-documentconverter-client-7.10.0/com.openexchange.documentconverter.client/src/com/openexchange/documentconverter/client/json/FileIdLock.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.documentconverter.client.json;

import java.util.concurrent.locks.ReentrantLock;

/**
 * {@link FileIdLock}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.8.4
 */
@SuppressWarnings("serial")
public class FileIdLock extends ReentrantLock {

    /**
     * Initializes a new {@link FileIdLock}.
     */
    public FileIdLock() {
        super();
        updateTimestamp();
    }

    /**
     * @return
     */
    public long getTimestampMillis() {
        return m_timestampMillis;
    }

    /**
     *
     */
    public void updateTimestamp() {
        m_timestampMillis = System.currentTimeMillis();
    }

    // - Members ---------------------------------------------------------------

    private long m_timestampMillis = 0;
}

==> open-xchange-documentconverter-client_7.10.1.orig.tar.bz2: open-xchange-documentconverter-client-7.10.1/com.openexchange.documentconverter.client/src/com/openexchange/documentconverter/client/json/FileIdLock.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.documentconverter.client.json;

import java.util.concurrent.locks.ReentrantLock;
import com.openexchange.documentconverter.NonNull;
import com.openexchange.filemanagement.ManagedFileManagement;

/**
 * {@link FileIdLock}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.8.4
 */
@SuppressWarnings("serial")
public class FileIdLock extends ReentrantLock {

    /**
     * Unused
     */
    @SuppressWarnings("unused")
    private void FileId() {
        // Unused
    }

    /**
     * Initializes a new {@link FileIdLock}.
     */
    public FileIdLock(@NonNull final String fileId) {
        super();

        this.fileId = fileId;

        updateTimestamp();
    }

    /**
     * @return
     */
    @NonNull public String getFileId() {
        return this.fileId;
    }

    /**
     * @return
     */
    public long getTimestampMillis() {
        return this.timestampMillis;
    }

    /**
     *
     */
    public void updateTimestamp() {
        this.timestampMillis = System.currentTimeMillis();
    }

    /**
     * @param fileManagement
     */
    public void holdManagedFile() {
        this.holdManagedFile = true;
    }

    /**
     * @param fileManagement
     */
    public void unholdManagedFile(ManagedFileManagement fileManagement) {
        this.holdManagedFile = false;
    }

    /**
     * @param fileManagement
     * @return
     */
    public boolean isManagedFileHeld() {
        return this.holdManagedFile;
    }

    // - Members ---------------------------------------------------------------

    private String fileId;

    private long timestampMillis = 0;

    private boolean holdManagedFile = false;
}
